==> jc-1.4.0.tar.gz: javax/swing/plaf/TableUI.h <==
// public abstract class javax.swing.plaf.TableUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 2b635ea4ac0d0574 javax_swing_plaf_TableUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_TableUI_H_
#define _JC_javax_swing_plaf_TableUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_TableUI$sub_refs	_jc_javax_swing_plaf_TableUI$sub_refs;
typedef struct _jc_javax_swing_plaf_TableUI$sub_nonrefs	_jc_javax_swing_plaf_TableUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_TableUI$refs	_jc_javax_swing_plaf_TableUI$refs;
typedef struct _jc_javax_swing_plaf_TableUI$nonrefs	_jc_javax_swing_plaf_TableUI$nonrefs;
typedef struct _jc_javax_swing_plaf_TableUI$object	_jc_javax_swing_plaf_TableUI$object;

typedef const struct _jc_javax_swing_plaf_TableUI$vmethods	_jc_javax_swing_plaf_TableUI$vmethods;
typedef const struct _jc_javax_swing_plaf_TableUI$vtable	_jc_javax_swing_plaf_TableUI$vtable;
typedef const struct _jc_javax_swing_plaf_TableUI$vtype	_jc_javax_swing_plaf_TableUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_TableUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_TableUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_TableUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_TableUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TableUI$vmethods	javax_swing_plaf_TableUI;
};

// Vtype
struct _jc_javax_swing_plaf_TableUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_TableUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_TableUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_TableUI$refs {
    _jc_javax_swing_plaf_TableUI$sub_refs	javax_swing_plaf_TableUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_TableUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_TableUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TableUI$sub_nonrefs	javax_swing_plaf_TableUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_TableUI$object {
	_jc_javax_swing_plaf_TableUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_TableUI$vtype	*vtype;
	_jc_javax_swing_plaf_TableUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_TableUI$vtype _jc_javax_swing_plaf_TableUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_TableUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_TableUI$class_object;

#endif	/* _JC_javax_swing_plaf_TableUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/TableUI.h <==
// public abstract class javax.swing.plaf.TableUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 2b635ea4ac0d0574 javax_swing_plaf_TableUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_TableUI_H_
#define _JC_javax_swing_plaf_TableUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_TableUI$sub_refs	_jc_javax_swing_plaf_TableUI$sub_refs;
typedef struct _jc_javax_swing_plaf_TableUI$sub_nonrefs	_jc_javax_swing_plaf_TableUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_TableUI$refs	_jc_javax_swing_plaf_TableUI$refs;
typedef struct _jc_javax_swing_plaf_TableUI$nonrefs	_jc_javax_swing_plaf_TableUI$nonrefs;
typedef struct _jc_javax_swing_plaf_TableUI$object	_jc_javax_swing_plaf_TableUI$object;

typedef const struct _jc_javax_swing_plaf_TableUI$vmethods	_jc_javax_swing_plaf_TableUI$vmethods;
typedef const struct _jc_javax_swing_plaf_TableUI$vtable	_jc_javax_swing_plaf_TableUI$vtable;
typedef const struct _jc_javax_swing_plaf_TableUI$vtype	_jc_javax_swing_plaf_TableUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_TableUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_TableUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_TableUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_TableUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TableUI$vmethods	javax_swing_plaf_TableUI;
};

// Vtype
struct _jc_javax_swing_plaf_TableUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_TableUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_TableUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_TableUI$refs {
    _jc_javax_swing_plaf_TableUI$sub_refs	javax_swing_plaf_TableUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_TableUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_TableUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TableUI$sub_nonrefs	javax_swing_plaf_TableUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_TableUI$object {
	_jc_javax_swing_plaf_TableUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_TableUI$vtype	*vtype;
	_jc_javax_swing_plaf_TableUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_TableUI$vtype _jc_javax_swing_plaf_TableUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_TableUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_TableUI$class_object;

#endif	/* _JC_javax_swing_plaf_TableUI_H_ */
